@@ -26,8 +26,6 @@ pub fn encrypt_file(
         exit(0);
     }
 
-    // add a check for "output file is larger than recommended, would you like to use stream encryption?"
-
     let raw_key = get_user_key(keyfile)?;
 
     let read_start_time = Instant::now();
@@ -35,6 +33,10 @@ pub fn encrypt_file(
     let read_duration = read_start_time.elapsed();
     println!("Read {} [took {:.2}s]", input, read_duration.as_secs_f32());
 
+    println!(
+        "Encrypting {} in normal mode (this may take a while)",
+        input
+    );
     let encrypt_start_time = Instant::now();
     let data = encrypt_bytes(file_contents, raw_key);
     let encrypt_duration = encrypt_start_time.elapsed();
