@@ -11,7 +11,7 @@ mod structs;
 
 fn main() -> Result<()> {
     let matches = Command::new("dexios")
-        .version("6.3.2")
+        .version("6.3.6")
         .author("brxken128 <github.com/brxken128>")
         .about("Secure command-line encryption of files.")
         .subcommand_required(true)
@@ -39,7 +39,7 @@ fn main() -> Result<()> {
                         .long("keyfile")
                         .value_name("file")
                         .takes_value(true)
-                        .help("use a keyfile for encryption"),
+                        .help("use a keyfile instead of a password"),
                 )
                 .arg(
                     Arg::new("erase")
@@ -100,7 +100,7 @@ fn main() -> Result<()> {
                         .long("keyfile")
                         .value_name("file")
                         .takes_value(true)
-                        .help("use a keyfile for encryption"),
+                        .help("use a keyfile instead of a password"),
                 )
                 .arg(
                     Arg::new("erase")
